@@ -41,7 +41,7 @@
 #' @param language Language to use, can be one of \code{'cs'}, \code{'da'},
 #'  \code{'de'}, \code{'en'}, \code{'es'}, \code{'fi'}, \code{'fr'},
 #'  \code{'hu'}, \code{'nl'}, \code{'pl'}, \code{'pt-BR'}, \\code{'pt'},
-#'  \code{'ro'}, \code{'ru'}, \code{'sk'}, \code{'zh'}.
+#'  \code{'ro'}, \code{'ru'}, \code{'sk'}, \code{'zh'}, \code{'ja'}.
 #' @param inline If \code{TRUE}, datepicker will always be visible.
 #' @param onlyTimepicker Display only the time picker.
 #' @param width The width of the input, e.g. \code{'400px'}, or \code{'100\%'}.
@@ -131,7 +131,7 @@ airDatepickerInput <- function(inputId,
   language <- match.arg(
     arg = language,
     choices = c("cs", "da", "de", "en", "es", "fi", "fr", "hu", "nl", "pl",
-                "pt-BR", "pt", "ro", "ru", "sk", "tr", "zh"),
+                "pt-BR", "pt", "ro", "ru", "sk", "tr", "zh", "ja"),
     several.ok = FALSE
   )
 
